@@ -23,7 +23,7 @@
 
 #include "xfce-arrow-button.h"
 #include "xfce-panel-macros.h"
-#include "libxfce4panel-alias.h"
+#include "libxfce4panel-visibility.h"
 
 #include "common/panel-private.h"
 
@@ -36,8 +36,8 @@
  *
  * Toggle button with (optional) arrow. The arrow direction will be
  * inverted when the button is toggled.
- * Since 4.8 it is also possible to make the button blink and pack additional
- * widgets in the button, using gtk_container_add().
+ * Since 4.8 it is also possible to make the button blink and pack an additional
+ * widget in the button, using gtk_container_add().
  **/
 
 
@@ -657,4 +657,4 @@ xfce_arrow_button_set_blinking (XfceArrowButton *button,
 
 
 #define __XFCE_ARROW_BUTTON_C__
-#include "libxfce4panel-aliasdef.c"
+#include "libxfce4panel-visibility.c"
