@@ -20,10 +20,9 @@
 #include "config.h"
 #endif
 
-#include "libxfce4panel/xfce-panel-macros.h"
-#include "libxfce4panel/xfce-panel-plugin-provider.h"
-
-#include "libxfce4panel/libxfce4panel-alias.h"
+#include "xfce-panel-macros.h"
+#include "xfce-panel-plugin-provider.h"
+#include "libxfce4panel-visibility.h"
 
 #include "common/panel-private.h"
 
@@ -76,6 +75,17 @@ xfce_panel_plugin_provider_get_unique_id (XfcePanelPluginProvider *provider)
 
 
 
+void
+xfce_panel_plugin_provider_emit_hidden_event (XfcePanelPluginProvider *provider,
+                                              gboolean hidden)
+{
+  panel_return_if_fail (XFCE_IS_PANEL_PLUGIN_PROVIDER (provider));
+
+  XFCE_PANEL_PLUGIN_PROVIDER_GET_IFACE (provider)->hidden_event (provider, hidden);
+}
+
+
+
 void
 xfce_panel_plugin_provider_set_size (XfcePanelPluginProvider *provider,
                                      gint size)
@@ -264,4 +274,4 @@ xfce_panel_plugin_provider_ask_remove (XfcePanelPluginProvider *provider)
 
 
 #define __XFCE_PANEL_PLUGIN_PROVIDER_C__
-#include "libxfce4panel/libxfce4panel-aliasdef.c"
+#include "libxfce4panel-visibility.c"
