@@ -1065,6 +1065,7 @@ panel_preferences_dialog_panel_add (GtkWidget *widget,
   /* create new window */
   window = panel_application_new_window (dialog->application,
                                          gtk_widget_get_screen (widget), -1, TRUE);
+  gtk_widget_show (GTK_WIDGET (window));
 
   /* rebuild the selector */
   panel_id = panel_window_get_id (window);
@@ -1754,6 +1755,9 @@ panel_preferences_dialog_item_selection_changed (GtkTreeSelection *selection,
               panel_return_if_fail (GTK_IS_WIDGET (object));
               gtk_widget_set_sensitive (GTK_WIDGET (object), FALSE);
             }
+          object = gtk_builder_get_object (GTK_BUILDER (dialog), "item-remove");
+          panel_return_if_fail (GTK_IS_WIDGET (object));
+          gtk_widget_set_sensitive (GTK_WIDGET (object), TRUE);
           g_list_free (selected);
           return;
         }
@@ -1763,6 +1767,10 @@ panel_preferences_dialog_item_selection_changed (GtkTreeSelection *selection,
       items = panel_itembar_get_n_children (PANEL_ITEMBAR (itembar)) - 1;
 
       /* update sensitivity of buttons */
+      object = gtk_builder_get_object (GTK_BUILDER (dialog), "item-add");
+      panel_return_if_fail (GTK_IS_WIDGET (object));
+      gtk_widget_set_sensitive (GTK_WIDGET (object), TRUE);
+
       object = gtk_builder_get_object (GTK_BUILDER (dialog), "item-up");
       panel_return_if_fail (GTK_IS_WIDGET (object));
       gtk_widget_set_sensitive (GTK_WIDGET (object), !!(position > 0 && position <= items));
@@ -1798,6 +1806,9 @@ panel_preferences_dialog_item_selection_changed (GtkTreeSelection *selection,
           panel_return_if_fail (GTK_IS_WIDGET (object));
           gtk_widget_set_sensitive (GTK_WIDGET (object), FALSE);
         }
+      object = gtk_builder_get_object (GTK_BUILDER (dialog), "item-add");
+      panel_return_if_fail (GTK_IS_WIDGET (object));
+      gtk_widget_set_sensitive (GTK_WIDGET (object), TRUE);
     }
 }
 
