@@ -20,7 +20,6 @@
 #include "config.h"
 #endif
 
-#include "directorymenu-dialog_ui.h"
 #include "directorymenu.h"
 
 #include "common/panel-private.h"
@@ -497,8 +496,7 @@ directory_menu_plugin_configure_plugin (XfcePanelPlugin *panel_plugin)
   GObject *dialog, *object;
 
   /* setup the dialog */
-  builder = panel_utils_builder_new (panel_plugin, directorymenu_dialog_ui,
-                                     directorymenu_dialog_ui_length, &dialog);
+  builder = panel_utils_builder_new (panel_plugin, "/org/xfce/panel/directorymenu-dialog.glade", &dialog);
   if (G_UNLIKELY (builder == NULL))
     return;
 
